# pyslim

[![License](https://img.shields.io/github/license/tskit-dev/pyslim)](https://github.com/tskit-dev/pyslim/blob/main/LICENSE) [![PyPI version](https://img.shields.io/pypi/v/pyslim.svg)](https://pypi.org/project/pyslim/) [![Supported Python Versions](https://img.shields.io/pypi/pyversions/pyslim.svg)](https://pypi.org/project/pyslim/) [![Docs Build](https://github.com/tskit-dev/pyslim/actions/workflows/docs.yml/badge.svg)](https://github.com/tskit-dev/pyslim/actions/workflows/docs.yml) [![Tests](https://github.com/tskit-dev/pyslim/actions/workflows/tests.yml/badge.svg)](https://github.com/tskit-dev/pyslim/actions/workflows/tests.yml) [![codecov](https://codecov.io/gh/tskit-dev/pyslim/branch/main/graph/badge.svg)](https://codecov.io/gh/tskit-dev/pyslim)

`pyslim` is a python module that provides a few extra tools for dealing with tree sequences
produced by SLiM and for preparing other tree sequences for use with SLiM.
Most tree sequence functionality is provided by [tskit](https://tskit.dev/tskit).
Please see [our documentation](https://tskit.dev/pyslim/docs/stable/) ([latest](https://tskit.dev/pyslim/docs/latest/)) for more information.
(That link is to documentation for the last release;
instead, [the latest](https://tskit.dev/pyslim/docs/latest) documentation
may have additional examples, but may also describe features you need to install from github to get.)

## Installation

To install `pyslim`, do
```
pip install pyslim
```
or read the documentation for how to [install from source](https://tskit.dev/pyslim/docs/stable/development.html#sec-development).

Alternatively, install from conda-forge:

```
conda install -c conda-forge pyslim
```

## Quickstart

See tutorials and examples at https://tskit.dev/pyslim/docs/stable/
